@@ -215,25 +215,31 @@ class Lastuser(object):
         """
         @wraps(f)
         def decorated_function(*args, **kwargs):
+            data = f(*args, **kwargs)
+            if 'cookietest' in request.args:
+                next = get_next_url()
+            else:
+                next = data.get('next') or get_next_url(referrer=True)
             if session.new and 'cookietest' not in request.args:
                 # Check if the user's browser supports cookies
                 session['cookies'] = True
                 # Reconstruct current URL with ?cookietest=1 or &cookietest=1 appended
                 url_parts = urlparse.urlsplit(request.url)
                 if url_parts.query:
-                    return redirect(request.url + '&cookietest=1')
+                    return redirect(request.url + '&cookietest=1&next=' + urllib.quote(next))
                 else:
-                    return redirect(request.url + '?cookietest=1')
+                    return redirect(request.url + '?cookietest=1&next=' + urllib.quote(next))
             else:
                 if session.new:
                     # No support for cookies. Abort login
                     return self._auth_error_handler('no_cookies',
-                        error_description=u"Your browser must accept cookies to login.",
+                        error_description=u"Your browser must accept cookies for you to login.",
                         error_uri="")
+                else:
+                    # The 'cookies' key is not needed anymore
+                    session.pop('cookies', None)
 
-            data = f(*args, **kwargs)
             scope = data.get('scope', 'id')
-            next = data.get('next') or get_next_url()
             return self._login_handler_internal(scope, next)
         self._login_handler = f
         return decorated_function
